@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -34,9 +35,7 @@
 #include <sal/types.h>
 #include <rtl/process.h>
 
-#ifndef _DOWRAPPERTRANSFERABLE_HXX_
 #include "DOTransferable.hxx"
-#endif
 #include "..\misc\ImplHelper.hxx"
 #include "..\misc\WinClip.hxx"
 #include "DTransHelper.hxx"
@@ -603,3 +602,5 @@ sal_Bool SAL_CALL CDOTransferable::cmpAllContentTypeParameter(
     return retVal;
 }
         
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
