@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -41,9 +42,7 @@
 #include <sot/formats.hxx>
 #include <sot/exchange.hxx>
 #include <unotools/ucbstreamhelper.hxx>
-#ifndef _TOOLS_FSYS_HXX
 #include <tools/fsys.hxx>
-#endif
 #include <tools/cachestr.hxx>
 #include <tools/debug.hxx>
 #include <tools/urlobj.hxx>
@@ -1561,3 +1560,4 @@ sal_Int32 SotStorage::GetVersion( const com::sun::star::uno::Reference < com::su
     return 0;
 }
 
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
