@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -40,10 +41,7 @@
 #include <algorithm>
 #include <vcl/bitmap.hxx>
 #include <tools/color.hxx>
-
-#ifndef _RTL_USTRING_HXX_
-#include <rtl/OUString.hxx>
-#endif
+#include <rtl/ustring.hxx>
 #include <memory>
 
 #define ROADMAP_INDENT_X        4
@@ -1023,3 +1021,5 @@ namespace svt
 //.........................................................................
 }	// namespace svt
 //.........................................................................
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
