@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -32,15 +33,9 @@
 
 
 #include "addresstemplate.hxx"
-#ifndef _SVT_ADDRESSTEMPLATE_HRC_
 #include "addresstemplate.hrc"
-#endif
-#ifndef _SVTOOLS_HRC
 #include <svtools/svtools.hrc>
-#endif
-#ifndef _SVT_HELPID_HRC
 #include <svtools/helpid.hrc>
-#endif
 #include <svtools/svtdata.hxx>
 #include <tools/debug.hxx>
 #include <comphelper/processfactory.hxx>
@@ -49,9 +44,7 @@
 #include <vcl/waitobj.hxx>
 #include <vcl/msgbox.hxx>
 #include <toolkit/helper/vclunohelper.hxx>
-#ifndef _CPPUHELPER_EXTRACT_HXX_
 #include <cppuhelper/extract.hxx>
-#endif
 #include <comphelper/interaction.hxx>
 #include <com/sun/star/ui/dialogs/XExecutableDialog.hpp>
 #include <com/sun/star/awt/XWindow.hpp>
@@ -66,9 +59,7 @@
 #include <com/sun/star/sdbcx/XColumnsSupplier.hpp>
 #include <com/sun/star/sdb/CommandType.hpp>
 #include "localresaccess.hxx"
-#ifndef SVTOOLS_FILENOTATION_HXX_
 #include "svl/filenotation.hxx"
-#endif
 #include <tools/urlobj.hxx>
 
 #include <algorithm>
@@ -1338,3 +1329,4 @@ void AssignmentPersistentData::Commit()
 }	// namespace svt
 // .......................................................................
 
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
