@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -28,14 +29,11 @@
 // MARKER(update_precomp.py): autogen include statement, do not remove
 #include "precompiled_svtools.hxx"
 #include <tools/debug.hxx>
-#ifndef _SV_APP_HXX
 #include <vcl/svapp.hxx>
-#endif
-#ifndef _VCL_PRINT_HXX
 #include <vcl/print.hxx>
-#endif
 #include <vcl/msgbox.hxx>
 #include <vcl/jobset.hxx>
+#include <sal/macros.h>
 #include <tools/urlobj.hxx>
 
 #include "printdlg.hrc"
@@ -45,9 +43,7 @@
 #include <svtools/svtdata.hxx>
 #include <filedlg.hxx>
 #include "svl/pickerhelper.hxx"
-#ifndef _SVT_HELPID_HRC
 #include <svtools/helpid.hrc>
-#endif
 #include <com/sun/star/ui/dialogs/TemplateDescription.hpp>
 #include <com/sun/star/ui/dialogs/ExecutableDialogResults.hpp>
 #include <com/sun/star/ui/dialogs/XFilePicker.hpp>
@@ -343,7 +339,7 @@ void PrintDialog::ImplInitControls()
                                 &maFlSepButtonLine, &maBtnOptions, &maBtnOK,
                                 &maBtnCancel, &maBtnHelp };
         Window** pCtrl = pControls;
-        const sal_Int32 nCount = sizeof( pControls ) / sizeof( pControls[0] );
+        const sal_Int32 nCount = SAL_N_ELEMENTS( pControls );
         for ( sal_Int32 i = 0; i < nCount; ++i, ++pCtrl )
         {
             if ( NULL == *pCtrl )
@@ -796,3 +792,4 @@ void PrintDialog::DisableHelp()
     maBtnHelp.Disable();
 }
 
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
