@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -31,7 +32,7 @@
 #include "descriptor.hxx"
 
 #include <rtl/uuid.h>
-#include <vos/mutex.hxx>
+#include <osl/mutex.hxx>
 #include <unotools/ucbstreamhelper.hxx>
 #include <svtools/filter.hxx>
 #include <svl/itemprop.hxx>
@@ -308,7 +309,7 @@ uno::Sequence< uno::Type > SAL_CALL GraphicDescriptor::getTypes()
 uno::Sequence< sal_Int8 > SAL_CALL GraphicDescriptor::getImplementationId()
     throw( uno::RuntimeException )
 {
-    vos::OGuard 						aGuard( Application::GetSolarMutex() );
+    SolarMutexGuard aGuard;
     static uno::Sequence< sal_Int8 >	aId;
     
     if( aId.getLength() == 0 )
@@ -324,7 +325,7 @@ uno::Sequence< sal_Int8 > SAL_CALL GraphicDescriptor::getImplementationId()
 
 ::comphelper::PropertySetInfo* GraphicDescriptor::createPropertySetInfo()
 {
-    vos::OGuard 					aGuard( Application::GetSolarMutex() );
+    SolarMutexGuard aGuard;
     ::comphelper::PropertySetInfo*	pRet = new ::comphelper::PropertySetInfo();
 
     static ::comphelper::PropertyMapEntry aEntries[] =
@@ -363,7 +364,7 @@ void GraphicDescriptor::_setPropertyValues( const comphelper::PropertyMapEntry**
 void GraphicDescriptor::_getPropertyValues( const comphelper::PropertyMapEntry** ppEntries, uno::Any* pValues )
     throw( beans::UnknownPropertyException, lang::WrappedTargetException )
 {
-    ::vos::OGuard aGuard( Application::GetSolarMutex() );
+    SolarMutexGuard aGuard;
 
     while( *ppEntries )
     {
@@ -496,3 +497,5 @@ void GraphicDescriptor::_getPropertyValues( const comphelper::PropertyMapEntry**
 }
 
 }
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
