@@ -1,7 +1,8 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
- * 
+ *
  * Copyright 2000, 2010 Oracle and/or its affiliates.
  *
  * OpenOffice.org - a multi-platform office productivity suite
@@ -28,7 +29,7 @@
 // MARKER(update_precomp.py): autogen include statement, do not remove
 #include "precompiled_svtools.hxx"
 
-#include <vos/timer.hxx>
+#include <salhelper/timer.hxx>
 #include <tools/debug.hxx>
 #include <vcl/outdev.hxx>
 #include <tools/poly.hxx>
@@ -75,7 +76,7 @@ public:
                     return( rID.mnID1 == mnID1 && rID.mnID2 == mnID2 &&
                             rID.mnID3 == mnID3 && rID.mnID4 == mnID4 );
                 }
-    
+
     ByteString	GetIDString() const;
     BOOL        IsEmpty() const { return( 0 == mnID4 ); }
 };
@@ -84,7 +85,7 @@ public:
 
 GraphicID::GraphicID( const GraphicObject& rObj )
 {
-    const Graphic& rGraphic = rObj.GetGraphic(); 
+    const Graphic& rGraphic = rObj.GetGraphic();
 
     mnID1 = ( (ULONG) rGraphic.GetType() ) << 28;
 
@@ -160,7 +161,7 @@ ByteString GraphicID::GetIDString() const
 class GraphicCacheEntry
 {
 private:
-    
+
     List				maGraphicObjectList;
     GraphicID			maID;
     GfxLink				maGfxLink;
@@ -168,23 +169,23 @@ private:
     GDIMetaFile*		mpMtf;
     Animation*			mpAnimation;
     BOOL				mbSwappedAll;
-                        
+
     BOOL				ImplInit( const GraphicObject& rObj );
     BOOL				ImplMatches( const GraphicObject& rObj ) const { return( GraphicID( rObj ) == maID ); }
     void				ImplFillSubstitute( Graphic& rSubstitute );
-                        
-public:					
-                        
+
+public:
+
                         GraphicCacheEntry( const GraphicObject& rObj );
                         ~GraphicCacheEntry();
 
     const GraphicID&	GetID() const { return maID; }
-                        
+
     void				AddGraphicObjectReference( const GraphicObject& rObj, Graphic& rSubstitute );
     BOOL				ReleaseGraphicObjectReference( const GraphicObject& rObj );
     ULONG				GetGraphicObjectReferenceCount() { return maGraphicObjectList.Count(); }
     BOOL				HasGraphicObjectReference( const GraphicObject& rObj );
-                        
+
     void				TryToSwapIn();
     void				GraphicObjectWasSwappedOut( const GraphicObject& rObj );
     BOOL				FillSwappedGraphicObject( const GraphicObject& rObj, Graphic& rSubstitute );
@@ -243,7 +244,7 @@ BOOL GraphicCacheEntry::ImplInit( const GraphicObject& rObj )
                     mpBmpEx = new BitmapEx( rGraphic.GetBitmapEx() );
             }
             break;
-                    
+
             case( GRAPHIC_GDIMETAFILE ):
             {
                 mpMtf = new GDIMetaFile( rGraphic.GetGDIMetaFile() );
@@ -311,13 +312,13 @@ void GraphicCacheEntry::ImplFillSubstitute( Graphic& rSubstitute )
 // -----------------------------------------------------------------------------
 
 void GraphicCacheEntry::AddGraphicObjectReference( const GraphicObject& rObj, Graphic& rSubstitute )
-{	
+{
     if( mbSwappedAll )
         mbSwappedAll = !ImplInit( rObj );
 
     ImplFillSubstitute( rSubstitute );
     maGraphicObjectList.Insert( (void*) &rObj, LIST_APPEND );
-}	
+}
 
 // -----------------------------------------------------------------------------
 
@@ -409,7 +410,7 @@ class GraphicDisplayCacheEntry
 {
 private:
 
-    ::vos::TTimeValue           maReleaseTime;
+    ::salhelper::TTimeValue     maReleaseTime;
     const GraphicCacheEntry*	mpRefCacheEntry;
     GDIMetaFile*				mpMtf;
     BitmapEx*					mpBmpEx;
@@ -419,15 +420,15 @@ private:
     ULONG						mnOutDevDrawMode;
     USHORT						mnOutDevBitCount;
 
-public:						
-                            
-    static ULONG				GetNeededSize( OutputDevice* pOut, const Point& rPt, const Size& rSz, 
+public:
+
+    static ULONG				GetNeededSize( OutputDevice* pOut, const Point& rPt, const Size& rSz,
                                                const GraphicObject& rObj, const GraphicAttr& rAttr );
-                            
-public:						
-                            
+
+public:
+
                                 GraphicDisplayCacheEntry( const GraphicCacheEntry* pRefCacheEntry,
-                                                          OutputDevice* pOut, const Point& rPt, const Size& rSz, 
+                                                          OutputDevice* pOut, const Point& rPt, const Size& rSz,
                                                           const GraphicObject& rObj, const GraphicAttr& rAttr,
                                                           const BitmapEx& rBmpEx ) :
                                     mpRefCacheEntry( pRefCacheEntry ),
@@ -438,9 +439,9 @@ public:
                                     mnOutDevBitCount( pOut->GetBitCount() )
                                     {
                                     }
-                                
+
                                 GraphicDisplayCacheEntry( const GraphicCacheEntry* pRefCacheEntry,
-                                                          OutputDevice* pOut, const Point& rPt, const Size& rSz, 
+                                                          OutputDevice* pOut, const Point& rPt, const Size& rSz,
                                                           const GraphicObject& rObj, const GraphicAttr& rAttr,
                                                           const GDIMetaFile& rMtf ) :
                                     mpRefCacheEntry( pRefCacheEntry ),
@@ -448,11 +449,11 @@ public:
                                     maAttr( rAttr ), maOutSizePix( pOut->LogicToPixel( rSz ) ),
                                     mnCacheSize( GetNeededSize( pOut, rPt, rSz, rObj, rAttr ) ),
                                     mnOutDevDrawMode( pOut->GetDrawMode() ),
-                                    mnOutDevBitCount( pOut->GetBitCount() ) 
+                                    mnOutDevBitCount( pOut->GetBitCount() )
                                     {
-                                    }	
-                                        
-                                
+                                    }
+
+
                                 ~GraphicDisplayCacheEntry();
 
     const GraphicAttr&			GetAttr() const { return maAttr; }
@@ -461,10 +462,10 @@ public:
     const GraphicCacheEntry*	GetReferencedCacheEntry() const { return mpRefCacheEntry; }
     ULONG					GetOutDevDrawMode() const { return mnOutDevDrawMode; }
     USHORT				GetOutDevBitCount()	const { return mnOutDevBitCount; }
-    
-    void                        SetReleaseTime( const ::vos::TTimeValue& rReleaseTime ) { maReleaseTime = rReleaseTime; }
-    const ::vos::TTimeValue&    GetReleaseTime() const { return maReleaseTime; }
-                                
+
+    void                        SetReleaseTime( const ::salhelper::TTimeValue& rReleaseTime ) { maReleaseTime = rReleaseTime; }
+    const ::salhelper::TTimeValue&    GetReleaseTime() const { return maReleaseTime; }
+
     BOOL						Matches( OutputDevice* pOut, const Point& /*rPtPixel*/, const Size& rSzPixel,
                                          const GraphicCacheEntry* pCacheEntry, const GraphicAttr& rAttr ) const
                                 {
@@ -480,13 +481,13 @@ public:
                                             ( pOut->GetBitCount() == mnOutDevBitCount ) &&
                                             ( pOut->GetDrawMode() == mnOutDevDrawMode ) );
                                 }
-                                
+
     void						Draw( OutputDevice* pOut, const Point& rPt, const Size& rSz ) const;
 };
 
 // -----------------------------------------------------------------------------
 
-ULONG GraphicDisplayCacheEntry::GetNeededSize( OutputDevice* pOut, const Point& /*rPt*/, const Size& rSz, 
+ULONG GraphicDisplayCacheEntry::GetNeededSize( OutputDevice* pOut, const Point& /*rPt*/, const Size& rSz,
                                                const GraphicObject& rObj, const GraphicAttr& rAttr )
 {
     const Graphic&      rGraphic = rObj.GetGraphic();
@@ -498,7 +499,7 @@ ULONG GraphicDisplayCacheEntry::GetNeededSize( OutputDevice* pOut, const Point&
         const Size aOutSizePix( pOut->LogicToPixel( rSz ) );
         const long nBitCount = pOut->GetBitCount();
 
-        if( ( aOutSizePix.Width() > MAX_BMP_EXTENT ) || 
+        if( ( aOutSizePix.Width() > MAX_BMP_EXTENT ) ||
             ( aOutSizePix.Height() > MAX_BMP_EXTENT ) )
         {
             nNeededSize = ULONG_MAX;
@@ -546,7 +547,7 @@ void GraphicDisplayCacheEntry::Draw( OutputDevice* pOut, const Point& rPt, const
         if( maAttr.IsRotated() )
         {
             Polygon aPoly( Rectangle( rPt, rSz ) );
-            
+
             aPoly.Rotate( rPt, maAttr.GetRotation() % 3600 );
             const Rectangle aRotBoundRect( aPoly.GetBoundRect() );
             pOut->DrawBitmapEx( aRotBoundRect.TopLeft(), aRotBoundRect.GetSize(), *mpBmpEx );
@@ -573,7 +574,7 @@ GraphicCache::GraphicCache( GraphicManager& rMgr, ULONG nDisplayCacheSize, ULONG
 }
 
 // -----------------------------------------------------------------------------
-                                           
+
 GraphicCache::~GraphicCache()
 {
     DBG_ASSERT( !maGraphicCache.Count(), "GraphicCache::~GraphicCache(): there are some GraphicObjects in cache" );
@@ -582,18 +583,18 @@ GraphicCache::~GraphicCache()
 
 // -----------------------------------------------------------------------------
 
-void GraphicCache::AddGraphicObject( const GraphicObject& rObj, Graphic& rSubstitute, 
+void GraphicCache::AddGraphicObject( const GraphicObject& rObj, Graphic& rSubstitute,
                                      const ByteString* pID, const GraphicObject* pCopyObj )
 {
     BOOL bInserted = FALSE;
 
-    if( !rObj.IsSwappedOut() && 
+    if( !rObj.IsSwappedOut() &&
         ( pID || ( pCopyObj && ( pCopyObj->GetType() != GRAPHIC_NONE ) ) || ( rObj.GetType() != GRAPHIC_NONE ) ) )
     {
         if( pCopyObj )
         {
             GraphicCacheEntry* pEntry = static_cast< GraphicCacheEntry* >( maGraphicCache.First() );
-        
+
             while( !bInserted && pEntry )
             {
                 if( pEntry->HasGraphicObjectReference( *pCopyObj ) )
@@ -607,43 +608,43 @@ void GraphicCache::AddGraphicObject( const GraphicObject& rObj, Graphic& rSubsti
                 }
             }
         }
-        
+
         if( !bInserted )
         {
             GraphicCacheEntry* pEntry = static_cast< GraphicCacheEntry* >( maGraphicCache.First() );
             ::std::auto_ptr< GraphicID > apID;
-            
+
             if( !pID )
             {
                 apID.reset( new GraphicID( rObj ) );
             }
-    
+
             while( !bInserted && pEntry )
             {
                 const GraphicID& rEntryID = pEntry->GetID();
-    
+
                 if( pID )
                 {
                     if( rEntryID.GetIDString() == *pID )
                     {
                         pEntry->TryToSwapIn();
-    
+
                         // since pEntry->TryToSwapIn can modify our current list, we have to
                         // iterate from beginning to add a reference to the appropriate
                         // CacheEntry object; after this, quickly jump out of the outer iteration
-                        for( pEntry = static_cast< GraphicCacheEntry* >( maGraphicCache.First() ); 
-                             !bInserted && pEntry; 
+                        for( pEntry = static_cast< GraphicCacheEntry* >( maGraphicCache.First() );
+                             !bInserted && pEntry;
                              pEntry = static_cast< GraphicCacheEntry* >( maGraphicCache.Next() ) )
                         {
                             const GraphicID& rID = pEntry->GetID();
-    
+
                             if( rID.GetIDString() == *pID )
                             {
                                 pEntry->AddGraphicObjectReference( rObj, rSubstitute );
                                 bInserted = TRUE;
                             }
                         }
-    
+
                         if( !bInserted )
                         {
                             maGraphicCache.Insert( new GraphicCacheEntry( rObj ), LIST_APPEND );
@@ -659,7 +660,7 @@ void GraphicCache::AddGraphicObject( const GraphicObject& rObj, Graphic& rSubsti
                         bInserted = TRUE;
                     }
                 }
-    
+
                 if( !bInserted )
                     pEntry = static_cast< GraphicCacheEntry* >( maGraphicCache.Next() );
             }
@@ -750,7 +751,7 @@ void GraphicCache::GraphicObjectWasSwappedIn( const GraphicObject& rObj )
         if( pEntry->GetID().IsEmpty() )
         {
             ReleaseGraphicObject( rObj );
-            AddGraphicObject( rObj, (Graphic&) rObj.GetGraphic(), NULL, NULL ); 
+            AddGraphicObject( rObj, (Graphic&) rObj.GetGraphic(), NULL, NULL );
         }
         else
             pEntry->GraphicObjectWasSwappedIn( rObj );
@@ -801,12 +802,12 @@ void GraphicCache::SetCacheTimeout( ULONG nTimeoutSeconds )
     if( mnReleaseTimeoutSeconds != nTimeoutSeconds )
     {
         GraphicDisplayCacheEntry*   pDisplayEntry = (GraphicDisplayCacheEntry*) maDisplayCache.First();
-        ::vos::TTimeValue           aReleaseTime;
+        ::salhelper::TTimeValue           aReleaseTime;
 
         if( ( mnReleaseTimeoutSeconds = nTimeoutSeconds ) != 0 )
         {
             osl_getSystemTime( &aReleaseTime );
-            aReleaseTime.addTime( ::vos::TTimeValue( nTimeoutSeconds, 0 ) );
+            aReleaseTime.addTime( ::salhelper::TTimeValue( nTimeoutSeconds, 0 ) );
         }
 
         while( pDisplayEntry )
@@ -830,16 +831,16 @@ void GraphicCache::ClearDisplayCache()
 
 // -----------------------------------------------------------------------------
 
-BOOL GraphicCache::IsDisplayCacheable( OutputDevice* pOut, const Point& rPt, const Size& rSz, 
+BOOL GraphicCache::IsDisplayCacheable( OutputDevice* pOut, const Point& rPt, const Size& rSz,
                                        const GraphicObject& rObj, const GraphicAttr& rAttr ) const
 {
-    return( GraphicDisplayCacheEntry::GetNeededSize( pOut, rPt, rSz, rObj, rAttr ) <= 
+    return( GraphicDisplayCacheEntry::GetNeededSize( pOut, rPt, rSz, rObj, rAttr ) <=
             GetMaxObjDisplayCacheSize() );
 }
 
 // -----------------------------------------------------------------------------
 
-BOOL GraphicCache::IsInDisplayCache( OutputDevice* pOut, const Point& rPt, const Size& rSz, 
+BOOL GraphicCache::IsInDisplayCache( OutputDevice* pOut, const Point& rPt, const Size& rSz,
                                      const GraphicObject& rObj, const GraphicAttr& rAttr ) const
 {
     const Point					aPtPixel( pOut->LogicToPixel( rPt ) );
@@ -874,13 +875,13 @@ ByteString GraphicCache::GetUniqueID( const GraphicObject& rObj ) const
 
     if( pEntry )
         aRet = pEntry->GetID().GetIDString();
-    
+
     return aRet;
 }
 
 // -----------------------------------------------------------------------------
 
-BOOL GraphicCache::CreateDisplayCacheObj( OutputDevice* pOut, const Point& rPt, const Size& rSz, 
+BOOL GraphicCache::CreateDisplayCacheObj( OutputDevice* pOut, const Point& rPt, const Size& rSz,
                                           const GraphicObject& rObj, const GraphicAttr& rAttr,
                                           const BitmapEx& rBmpEx )
 {
@@ -892,18 +893,18 @@ BOOL GraphicCache::CreateDisplayCacheObj( OutputDevice* pOut, const Point& rPt,
         if( nNeededSize > GetFreeDisplayCacheSize() )
             ImplFreeDisplayCacheSpace( nNeededSize - GetFreeDisplayCacheSize() );
 
-        GraphicDisplayCacheEntry* pNewEntry = new GraphicDisplayCacheEntry( ImplGetCacheEntry( rObj ), 
+        GraphicDisplayCacheEntry* pNewEntry = new GraphicDisplayCacheEntry( ImplGetCacheEntry( rObj ),
                                                                             pOut, rPt, rSz, rObj, rAttr, rBmpEx );
 
         if( GetCacheTimeout() )
         {
-            ::vos::TTimeValue aReleaseTime;
+            ::salhelper::TTimeValue aReleaseTime;
 
             osl_getSystemTime( &aReleaseTime );
-            aReleaseTime.addTime( ::vos::TTimeValue( GetCacheTimeout(), 0 ) );
+            aReleaseTime.addTime( ::salhelper::TTimeValue( GetCacheTimeout(), 0 ) );
             pNewEntry->SetReleaseTime( aReleaseTime );
         }
-                                                                            
+
         maDisplayCache.Insert( pNewEntry, LIST_APPEND );
         mnUsedDisplaySize += pNewEntry->GetCacheSize();
         bRet = TRUE;
@@ -914,7 +915,7 @@ BOOL GraphicCache::CreateDisplayCacheObj( OutputDevice* pOut, const Point& rPt,
 
 // -----------------------------------------------------------------------------
 
-BOOL GraphicCache::CreateDisplayCacheObj( OutputDevice* pOut, const Point& rPt, const Size& rSz, 
+BOOL GraphicCache::CreateDisplayCacheObj( OutputDevice* pOut, const Point& rPt, const Size& rSz,
                                           const GraphicObject& rObj, const GraphicAttr& rAttr,
                                           const GDIMetaFile& rMtf )
 {
@@ -926,18 +927,18 @@ BOOL GraphicCache::CreateDisplayCacheObj( OutputDevice* pOut, const Point& rPt,
         if( nNeededSize > GetFreeDisplayCacheSize() )
             ImplFreeDisplayCacheSpace( nNeededSize - GetFreeDisplayCacheSize() );
 
-        GraphicDisplayCacheEntry* pNewEntry = new GraphicDisplayCacheEntry( ImplGetCacheEntry( rObj ), 
+        GraphicDisplayCacheEntry* pNewEntry = new GraphicDisplayCacheEntry( ImplGetCacheEntry( rObj ),
                                                                             pOut, rPt, rSz, rObj, rAttr, rMtf );
 
         if( GetCacheTimeout() )
         {
-            ::vos::TTimeValue aReleaseTime;
+            ::salhelper::TTimeValue aReleaseTime;
 
             osl_getSystemTime( &aReleaseTime );
-            aReleaseTime.addTime( ::vos::TTimeValue( GetCacheTimeout(), 0 ) );
+            aReleaseTime.addTime( ::salhelper::TTimeValue( GetCacheTimeout(), 0 ) );
             pNewEntry->SetReleaseTime( aReleaseTime );
         }
-                                                                            
+
         maDisplayCache.Insert( pNewEntry, LIST_APPEND );
         mnUsedDisplaySize += pNewEntry->GetCacheSize();
         bRet = TRUE;
@@ -948,7 +949,7 @@ BOOL GraphicCache::CreateDisplayCacheObj( OutputDevice* pOut, const Point& rPt,
 
 // -----------------------------------------------------------------------------
 
-BOOL GraphicCache::DrawDisplayCacheObj( OutputDevice* pOut, const Point& rPt, const Size& rSz, 
+BOOL GraphicCache::DrawDisplayCacheObj( OutputDevice* pOut, const Point& rPt, const Size& rSz,
                                         const GraphicObject& rObj, const GraphicAttr& rAttr )
 {
     const Point					aPtPixel( pOut->LogicToPixel( rPt ) );
@@ -961,7 +962,7 @@ BOOL GraphicCache::DrawDisplayCacheObj( OutputDevice* pOut, const Point& rPt, co
     {
         if( pDisplayCacheEntry->Matches( pOut, aPtPixel, aSzPixel, pCacheEntry, rAttr ) )
         {
-            ::vos::TTimeValue aReleaseTime;
+            ::salhelper::TTimeValue aReleaseTime;
 
             // put found object at last used position
             maDisplayCache.Insert( maDisplayCache.Remove( pDisplayCacheEntry ), LIST_APPEND );
@@ -969,7 +970,7 @@ BOOL GraphicCache::DrawDisplayCacheObj( OutputDevice* pOut, const Point& rPt, co
             if( GetCacheTimeout() )
             {
                 osl_getSystemTime( &aReleaseTime );
-                aReleaseTime.addTime( ::vos::TTimeValue( GetCacheTimeout(), 0 ) );
+                aReleaseTime.addTime( ::salhelper::TTimeValue( GetCacheTimeout(), 0 ) );
             }
 
             pDisplayCacheEntry->SetReleaseTime( aReleaseTime );
@@ -1036,14 +1037,14 @@ IMPL_LINK( GraphicCache, ReleaseTimeoutHdl, Timer*, pTimer )
 {
     pTimer->Stop();
 
-    ::vos::TTimeValue           aCurTime;
+    ::salhelper::TTimeValue           aCurTime;
     GraphicDisplayCacheEntry*   pDisplayEntry = (GraphicDisplayCacheEntry*) maDisplayCache.First();
 
     osl_getSystemTime( &aCurTime );
 
     while( pDisplayEntry )
     {
-        const ::vos::TTimeValue& rReleaseTime = pDisplayEntry->GetReleaseTime();
+        const ::salhelper::TTimeValue& rReleaseTime = pDisplayEntry->GetReleaseTime();
 
         if( !rReleaseTime.isEmpty() && ( rReleaseTime < aCurTime ) )
         {
@@ -1060,3 +1061,5 @@ IMPL_LINK( GraphicCache, ReleaseTimeoutHdl, Timer*, pTimer )
 
     return 0;
 }
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
