@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -181,7 +182,7 @@ INT32 HTMLOption::GetSNumber() const
     return aTmp.ToInt32();
 }
 
-void HTMLOption::GetNumbers( SvULongs &rLongs, BOOL bSpaceDelim ) const
+void HTMLOption::GetNumbers( SvULongs &rLongs, sal_Bool bSpaceDelim ) const
 {
     if( rLongs.Count() )
         rLongs.Remove( 0, rLongs.Count() );
@@ -323,6 +324,9 @@ HTMLParser::HTMLParser( SvStream& rIn, int bReadNewDoc )
         bReadComment = FALSE;
     bIsInHeader = TRUE;
     pOptions = new HTMLOptions;
+
+    //#i76649, default to UTF-8 for HTML unless we know differently
+    SetSrcEncoding(RTL_TEXTENCODING_UTF8);
 }
 
 HTMLParser::~HTMLParser()
@@ -441,9 +445,7 @@ int HTMLParser::FilterToken( int nToken )
 #define HTML_ISALNUM( c ) ( HTML_ISALPHA(c) || HTML_ISDIGIT(c) )
 #define HTML_ISSPACE( c ) ( ' ' == c || (c >= 0x09 && c <= 0x0d) )
 #define HTML_ISPRINTABLE( c ) ( c >= 32 && c != 127)
-// --> OD 2006-07-26 #138464#
 #define HTML_ISHEXDIGIT( c ) ( HTML_ISDIGIT(c) || (c >= 'A' && c <= 'F') || (c >= 'a' && c <= 'f') )
-// <--
 
 int HTMLParser::ScanText( const sal_Unicode cBreak )
 {
@@ -470,8 +472,6 @@ int HTMLParser::ScanText( const sal_Unicode cBreak )
                 if( '#' == (nNextCh = GetNextChar()) )
                 {
                     nNextCh = GetNextChar();
-                    // --> OD 2006-07-26 #138464#
-                    // consider hexadecimal digits
                     const sal_Bool bIsHex( 'x' == nNextCh );
                     const sal_Bool bIsDecOrHex( bIsHex || HTML_ISDIGIT(nNextCh) );
                     if ( bIsDecOrHex )
@@ -517,7 +517,6 @@ int HTMLParser::ScanText( const sal_Unicode cBreak )
                             }
                         }
                     }
-                    // <--
                     else
                         nNextCh = 0U;
                 }
@@ -1906,9 +1905,9 @@ int HTMLParser::FilterListing( int nToken )
     return nToken;
 }
 
-FASTBOOL HTMLParser::IsHTMLFormat( const sal_Char* pHeader,
-                                   BOOL bSwitchToUCS2,
-                                   rtl_TextEncoding eEnc )
+bool HTMLParser::IsHTMLFormat( const sal_Char* pHeader,
+                               BOOL bSwitchToUCS2,
+                               rtl_TextEncoding eEnc )
 {
     // Einer der folgenden regulaeren Ausdrucke muss sich auf den String
     // anwenden lassen, damit das Dok ein HTML-Dokument ist.
@@ -2369,3 +2368,4 @@ BOOL HTMLParser::SetEncodingByHTTPHeader(
 }
 
 
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
