@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -34,9 +35,7 @@
 #include <rtl/instance.hxx>
 #include <comphelper/property.hxx>
 #include <comphelper/sequence.hxx>
-#ifndef _COM_SUN_STAR_XNAMECONTAINER_HPP_
 #include <toolkit/controls/eventcontainer.hxx>
-#endif
 #include <toolkit/helper/property.hxx>
 #include <tools/debug.hxx>
 #include <algorithm>
@@ -651,3 +650,5 @@
 //........................................................................
 // }	// namespace toolkit
 //........................................................................
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
