@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -28,9 +29,7 @@
 // MARKER(update_precomp.py): autogen include statement, do not remove
 #include "precompiled_tools.hxx"
 
-#ifndef _LIMITS_H
 #include <limits.h>
-#endif
 #include <tools/debug.hxx>
 #include <tools/fract.hxx>
 #include <tools/stream.hxx>
@@ -734,3 +733,5 @@ SvStream& operator << ( SvStream& rOStream, const Fraction& rFract )
     rOStream << rFract.nDenominator;
     return rOStream;
 }
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
