@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -27,12 +28,6 @@
 
 // MARKER(update_precomp.py): autogen include statement, do not remove
 #include "precompiled_unotools.hxx"
-#ifndef GCC
-#endif
-
-//_________________________________________________________________________________________________________________
-//	includes
-//_________________________________________________________________________________________________________________
 
 #include <unotools/moduleoptions.hxx>
 #include <comphelper/sequenceashashmap.hxx>
@@ -1595,3 +1590,4 @@ SvtModuleOptions::EFactory SvtModuleOptions::ClassifyFactoryByModel(const css::u
     return aModule;
 }
 
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
