@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -610,12 +611,6 @@ BOOL AquaSalFrame::GetWindowState( SalFrameState* pState )
                      SAL_FRAMESTATE_MASK_Y                 |
                      SAL_FRAMESTATE_MASK_WIDTH             |
                      SAL_FRAMESTATE_MASK_HEIGHT            |
-                     #if 0
-                     SAL_FRAMESTATE_MASK_MAXIMIZED_X       |
-                     SAL_FRAMESTATE_MASK_MAXIMIZED_Y       |
-                     SAL_FRAMESTATE_MASK_MAXIMIZED_WIDTH   |
-                     SAL_FRAMESTATE_MASK_MAXIMIZED_HEIGHT  |
-                     #endif
                      SAL_FRAMESTATE_MASK_STATE;
 
     NSRect aStateRect = [mpWindow frame];
@@ -669,6 +664,10 @@ void AquaSalFrame::SetScreenNumber(unsigned int nScreen)
     }
 }
 
+void AquaSalFrame::SetApplicationID( const rtl::OUString &/*rApplicationID*/ )
+{
+}
+
 // -----------------------------------------------------------------------
 
 void AquaSalFrame::ShowFullScreen( BOOL bFullScreen, sal_Int32 nDisplay )
@@ -1171,6 +1170,8 @@ void AquaSalFrame::UpdateSettings( AllSettings& rSettings )
     getResolution( nDPIX, nDPIY );
     aAppFont = getFont( [NSFont systemFontOfSize: 0], nDPIY, aAppFont );
 
+    aStyleSettings.SetToolbarIconSize( nDPIY > 160 ? STYLE_TOOLBAR_ICONSIZE_LARGE : STYLE_TOOLBAR_ICONSIZE_SMALL );
+
     // TODO: better mapping of aqua<->ooo font settings
     aStyleSettings.SetAppFont( aAppFont );
     aStyleSettings.SetHelpFont( aAppFont );
@@ -1224,7 +1225,7 @@ void AquaSalFrame::UpdateSettings( AllSettings& rSettings )
     aStyleSettings.SetScrollBarSize( static_cast<long int>([NSScroller scrollerWidth]) );
 
     // images in menus false for MacOSX
-    aStyleSettings.SetUseImagesInMenus( false );
+    aStyleSettings.SetPreferredUseImagesInMenus( false );
     
     rSettings.SetStyleSettings( aStyleSettings );
 
@@ -1436,6 +1437,17 @@ SalPointerState	AquaSalFrame::GetPointerState()
     return state;
 }
 
+SalFrame::SalIndicatorState AquaSalFrame::GetIndicatorState()
+{
+    SalIndicatorState aState;
+    aState.mnState = 0;
+    return aState;
+}
+
+void AquaSalFrame::SimulateKeyPress( USHORT /*nKeyCode*/ )
+{
+}
+
 bool AquaSalFrame::SetPluginParent( SystemParentData* pNewParent )
 {
     // plugin parent may be killed unexpectedly by
@@ -1634,3 +1646,4 @@ void AquaSalFrame::EndSetClipRegion()
     }
 }
 
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
