@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -34,9 +35,7 @@
 #include <tools/debug.hxx>
 #include <tools/bigint.hxx>
 
-#ifndef _SV_RC_H
 #include <tools/rc.h>
-#endif
 
 #include <vcl/event.hxx>
 #include <vcl/svapp.hxx>
@@ -857,3 +856,5 @@ USHORT LongCurrencyBox::GetValuePos( BigInt nValue ) const
 }
 
 // =======================================================================
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
