@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -36,9 +37,7 @@
 #include <vcl/outfont.hxx>
 #include <rtl/alloc.h>
 
-#ifndef _RTL_TENCINFO_H_
 #include <rtl/tencinfo.h>
-#endif
 
 #include <set>
 
@@ -999,3 +998,5 @@ BitmapXlfdStorage::AddBitmapFont( const Xlfd *pXlfd )
     pBitmapXlfd->AddEncoding( pXlfd );
     Add( pBitmapXlfd );
 }
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
