@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -35,9 +36,7 @@
 #include <wincomp.hxx>
 #include <salbmp.h>
 #include <saldata.hxx>
-#ifndef _SV_SALIDS_HRC
 #include <salids.hrc>
-#endif
 #include <salgdi.h>
 #include <salframe.h>
 
@@ -819,3 +818,5 @@ void WinSalGraphics::invert( ULONG nPoints, const SalPoint* pPtAry, SalInvert nS
         SelectBrush( mhDC, hOldBrush );
     }
 }
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
